//******************************************************************************
// The software is testing the basic functions implemented in the GLCD graphic 
// library.
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.30
//******************************************************************************

#include <xc.h>

#define SYSTEM_CLOCK 32000000UL

#include "LTlib.h"

#include "HW_mini_Sensing_PIC_Board.h"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_IO.h"
#include "module_IO.c"

#include "module_ADC.h"  
#include "module_ADC.c" 

#include "module_I2C.h"
#include "module_I2C.c"

#define SSD1306_I2C_MODULE_2 

#include "OLED_SSD1306.h"
#include "OLED_SSD1306.c"

#include "display_utilities.h"
#include "display_utilities.c"

//Values for 10bits resolution
#define SW1_THRESHOLD 0
#define SW2_THRESHOLD 512 
#define SW3_THRESHOLD 683 

#define SW_DELTA 10 


//*************************************
//           
//*************************************
int main(void) {
    
    uint8_t buffer [10];
    uint16_t ADC_value = 0;
        
    IO_set_all_ports_as_inputs();
   
    delay_set_quartz(20);
   
    delay_ms (100);
    
    Display_initialize ();
   
    Display_set_double_buffer_state (DISPLAY_DOUBLE_BUFFER_ON);
    
    Display_write_message (10,5,"SW 1 : ");
    Display_write_message (10,15,"SW 2 : ");
    Display_write_message (10,25,"SW 3 : ");
    Display_write_message (10,45,"Voltage: ");
    
    while (1) {
                      
        ADC_value = ADC_read_channel(ADC_CH7); 
        
        LTlib_int16_to_string (buffer, ADC_value);    
        
        //Test SW1               
        if ( (ADC_value >= (SW1_THRESHOLD - SW_DELTA)) && (ADC_value <= (SW1_THRESHOLD + SW_DELTA))){
            Display_write_message (50,5,"Pressed");
        }else {
            Display_write_message (50,5,"-      ");
        } 
        
        //Test SW2               
        if ( (ADC_value >= (SW2_THRESHOLD - SW_DELTA)) && (ADC_value <= (SW2_THRESHOLD + SW_DELTA))){
            Display_write_message (50,15,"Pressed");
        }else {
            Display_write_message (50,15,"-      ");
        } 
        
        //Test SW3               
        if ( (ADC_value >= (SW3_THRESHOLD - SW_DELTA)) && (ADC_value <= (SW3_THRESHOLD + SW_DELTA))){
            Display_write_message (50,25,"Pressed");
        }else {
            Display_write_message (50,25,"-      ");
        } 
        
                
        Display_write_message(60,45, "   " );
        Display_write_string(60,45, buffer );
        
        Display_update_double_buffer ();
        
    }
    
}
    